import cwms.environment.*;
import hec.environment.*;
import java.rmi.*;

/**
 * Driver class to test normal (user/os) and CWMS implementations of the hec.environment.Environment 
 * interface in local and remote modes.
 * 
 * @see EnvServer
 */
public class EnvClient {
	
	public static void main (String args[]) throws Exception {

		Environment userEnv = null;
		Environment cwmsEnv = null;

		if (args.length > 0) {
			String hecUrl  = "//" + args[0] + "/UserEnv";
			String cwmsUrl = "//" + args[0] + "/CwmsEnv";
			System.out.println("Using object at " + hecUrl + "...");
			userEnv  = (Environment)Naming.lookup(hecUrl);
			System.out.println("Using object at " + cwmsUrl + "...");
			cwmsEnv = (Environment)Naming.lookup(cwmsUrl);
		}
		else {
			System.out.println("Using a local object...");
			userEnv  = new EnvironmentImpl();
			cwmsEnv = new CwmsEnvironmentImpl();
		}

		System.out.println("\nThe following USER calls should succeed...\n");
		System.out.println("USER_HOME       : " + userEnv.getUserHome());
		System.out.println("USER_APPDATA    : " + userEnv.getUserAppData());
		System.out.println("USER_DOCS       : " + userEnv.getUserDocs());
		System.out.println("COMMON_APPDATA  : " + userEnv.getCommonAppData());
		System.out.println("COMMON_DOCS     : " + userEnv.getCommonDocs());
		System.out.println("PROGRAM_INSTALL : " + userEnv.getProgramInstall());

		System.out.println("\nThe following USER call should throw a StdPathnameException...\n");
		try {
			System.out.println("JUNK            : " + userEnv.getStdPathname(0x7777));
		}
		catch (StdPathnameException e) {
			System.err.println("\t" + e.toString());
		}

		System.out.println("\nThe following CWMS calls should succeed...\n");
		System.out.println("USER_HOME       : " + cwmsEnv.getUserHome());
		System.out.println("USER_APPDATA    : " + cwmsEnv.getUserAppData());
		System.out.println("USER_DOCS       : " + cwmsEnv.getUserDocs());
		System.out.println("COMMON_APPDATA  : " + cwmsEnv.getCommonAppData());
		System.out.println("COMMON_DOCS     : " + cwmsEnv.getCommonDocs());
		System.out.println("PROGRAM_INSTALL : " + cwmsEnv.getProgramInstall());

		System.out.println("\nThe following CWMS call should throw a CwmsStdPathnameException...\n");
		try {                             
			System.out.println("JUNK            : " + cwmsEnv.getStdPathname(0x7777));
		}
		catch (CwmsStdPathnameException e) {
			System.err.println("\t" + e.toString());
		}

		System.out.println("\nALL DONE");
	}
}
