package hec.environment;

/**
 * Operating system independent implementation of the Environment interface
 * 
 * @see Environment
 */
public class EnvironmentImpl implements Environment {

	public EnvironmentImpl() throws Exception {}
	
	/**
	 * Get the operating-system dependent pathname represented by the pathname_id.
	 *
	 * @param pathname_id
	 *               The constant representing the desired pathname.
	 *
	 * @return The desired pathname.
	 */
	public String getStdPathname(int pathname_id) throws Exception {
		
		return StdPathnameFactory.getInstance().getStdPathname(pathname_id);
	}
	/**
	 * Get the operating-system dependent user home pathname.
	 *
	 * @return The user home pathname.
	 */
	public String getUserHome() throws Exception {
		
		return StdPathnameFactory.getInstance().getUserHome();
	}
	/**
	 * Get the operating-system dependent shared docuements pathname.
	 *
	 * @return The shared documents pathname.
	 */
	public String getCommonDocs() throws Exception {
		
		return StdPathnameFactory.getInstance().getCommonDocs();
	}
	/**
	 * Get the operating-system dependent user application data pathname.
	 *
	 * @return The user application data pathname.
	 */
	public String getUserAppData() throws Exception {

		return StdPathnameFactory.getInstance().getUserAppData();
	}
	/**
	 * Get the operating-system dependent user docuements pathname.
	 *
	 * @return The user documents pathname.
	 */
	public String getUserDocs() throws Exception {

		return StdPathnameFactory.getInstance().getUserDocs();
	}
	/**
	 * Get the operating-system dependent shared application data pathname.
	 *
	 * @return The shared application data pathname.
	 */
	public String getCommonAppData() throws Exception {

		return StdPathnameFactory.getInstance().getCommonAppData();
	}
	/**
	 * Get the operating-system dependent program installation pathname.
	 *
	 * @return The program installation pathname.
	 */
	public String getProgramInstall() throws Exception {

		return StdPathnameFactory.getInstance().getProgramInstall();
	}
}
