package hec.environment;

/**
 * Windows-specific implementation of StdPathnames interface.
 */
class WindowsStdPathnameImpl implements StdPathnames {

	/**
	 * Get the Windows-specific pathname represented by the pathname_id.
	 * 
	 * @param pathname_id
	 *               The constant representing the desired pathname.
	 * 
	 * @return The desired pathname.
	 */
	public String getStdPathname(int pathname_id) throws Exception {

		switch(pathname_id) {
			case USER_HOME       : break;
			case USER_APPDATA    : break;
			case USER_DOCS       : break;
			case COMMON_APPDATA  : break;
			case COMMON_DOCS     : break;
			case PROGRAM_INSTALL : break;
			default              :
				throw new StdPathnameException("Invalid pathname ID: " + pathname_id);
		}
		return WindowsEnvironment.getFolderPath(pathname_id);
	}

	/**
	 * Get the Windows-specific user home pathname.
	 * 
	 * @return The user home pathname.
	 */
	public String getUserHome() throws Exception {

		return getStdPathname(USER_HOME);
	}

	/**
	 * Get the Windows-specific user application data pathname.
	 * 
	 * @return The user application data pathname.
	 */
	public String getUserAppData() throws Exception {

		return getStdPathname(USER_APPDATA);
	}

	/**
	 * Get the Windows-specific user docuements pathname.
	 * 
	 * @return The user documents pathname.
	 */
	public String getUserDocs() throws Exception {

		return getStdPathname(USER_DOCS);
	}

	/**
	 * Get the Windows-specific shared application data pathname.
	 * 
	 * @return The shared application data pathname.
	 */
	public String getCommonAppData() throws Exception {

		return getStdPathname(COMMON_APPDATA);
	}

	/**
	 * Get the Windows-specific shared docuements pathname.
	 * 
	 * @return The shared documents pathname.
	 */
	public String getCommonDocs() throws Exception {

		return getStdPathname(COMMON_DOCS);
	}

	/**
	 * Get the Windows-specific program installation pathname.
	 * 
	 * @return The program installation pathname.
	 */
	public String getProgramInstall() throws Exception {

		return getStdPathname(PROGRAM_INSTALL);
	}

}
